/*
* This file is part of Bielefeld Type Library (BTL).
*
* Copyright(c) Frederic Siepmann
* http://opensource.cit-ec.de/projects/btl
*
* This file may be licensed under the terms of of the
* GNU Lesser General Public License Version 3 (the ``LGPL''),
* or (at your option) any later version.
*
* Software distributed under the License is distributed
* on an ``AS IS'' basis, WITHOUT WARRANTY OF ANY KIND, either
* express or implied. See the LGPL for the specific language
* governing rights and limitations.
*
* You should have received a copy of the LGPL along with this
* program. If not, go to http://www.gnu.org/licenses/lgpl.html
* or write to the Free Software Foundation, Inc.,
* 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
*
* The development of this software was supported by the
* Excellence Cluster EXC 277 Cognitive Interaction Technology.
* The Excellence Cluster EXC 277 is a grant of the Deutsche
* Forschungsgemeinschaft (DFG) in the context of the German
* Excellence Initiative.
*
* Contributors: Leon Ziegler, Johannes Wienke, Matthias Schröder, Norman Köster,
* 				Lukas Twardon, Torben Töniges, Annika Rothert, Marian Pohling,
* 				Denis Schulze, Viktor Richter, Birte Carlmeyer, Maikel Linke
*/

/*
 * CameraTargetData.h
 *
 *  Created on: Aug 6, 2009
 *      Author: jwienke
 */

#ifndef CAMERATARGETDATA_H_
#define CAMERATARGETDATA_H_

#include "Type.h"

namespace airobots {

class CameraTargetData: public Type {

public:

	static std::string getBaseTag();

	static std::string getTemplate();

	CameraTargetData();

	/**
	 * Returns the distance of the target to focus in laser coordinates (mm).
	 */
	double getDistance() const;
	void setDistance(double distance);

	/**
	 * Returns the height of the target to focus in mm over floor.
	 */
	double getHeight() const;
	void setHeight(double height);

	/**
	 * Returns the azimuth angle of the target to focus relative to the camera in
	 * rad.
	 * TODO what is angle 0?
	 */
	double getAzimuth() const;
	void setAzimuth(double azimuth);

	/**
	 * Returns the desired zoom level as percent of the maximum zoom of the
	 * camera [0,1].
	 */
	double getZoom() const;
	void setZoom(double zoom);

	void sanitizeLocation(xmltio::Location &loc) const;
	void fillInto(xmltio::Location &loc) const;
	static void fromLocation(const xmltio::Location &loc, CameraTargetData &type);

private:

	double distance;
	double height;
	double azimuth;

	double zoom;

};

}

#endif /* CAMERATARGETDATA_H_ */
