/*
* This file is part of Bielefeld Type Library (BTL).
*
* Copyright(c) Frederic Siepmann
* http://opensource.cit-ec.de/projects/btl
*
* This file may be licensed under the terms of of the
* GNU Lesser General Public License Version 3 (the ``LGPL''),
* or (at your option) any later version.
*
* Software distributed under the License is distributed
* on an ``AS IS'' basis, WITHOUT WARRANTY OF ANY KIND, either
* express or implied. See the LGPL for the specific language
* governing rights and limitations.
*
* You should have received a copy of the LGPL along with this
* program. If not, go to http://www.gnu.org/licenses/lgpl.html
* or write to the Free Software Foundation, Inc.,
* 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
*
* The development of this software was supported by the
* Excellence Cluster EXC 277 Cognitive Interaction Technology.
* The Excellence Cluster EXC 277 is a grant of the Deutsche
* Forschungsgemeinschaft (DFG) in the context of the German
* Excellence Initiative.
*
* Contributors: Leon Ziegler, Johannes Wienke, Matthias Schröder, Norman Köster,
* 				Lukas Twardon, Torben Töniges, Annika Rothert, Marian Pohling,
* 				Denis Schulze, Viktor Richter, Birte Carlmeyer, Maikel Linke
*/

#ifndef IMAGEDATA_H_
#define IMAGEDATA_H_

#include <xmltio/xmltio.hpp>

#include "Type.h"

namespace airobots {

class ImageData : public Type {

public:

	ImageData();
	virtual ~ImageData();

	static std::string getBaseTag();
	static std::string getTemplate();

	void sanitizeLocation(xmltio::Location &loc) const;
	virtual void fillInto(xmltio::Location &loc) const;
	static void fromLocation(const xmltio::Location &loc, ImageData &type);

    std::string getColorspace() const;
    int getHeight() const;
    std::string getUri() const;
    int getWidth() const;

    void setColorspace(std::string colorspace);
    void setHeight(int height);
    void setUri(std::string uri);
    void setWidth(int width);

private:

	std::string uri;
	int width;
	int height;
	std::string colorspace;

};

}

#endif /* IMAGEDATA_H_ */
