/*
* This file is part of Bielefeld Type Library (BTL).
*
* Copyright(c) Frederic Siepmann
* http://opensource.cit-ec.de/projects/btl
*
* This file may be licensed under the terms of of the
* GNU Lesser General Public License Version 3 (the ``LGPL''),
* or (at your option) any later version.
*
* Software distributed under the License is distributed
* on an ``AS IS'' basis, WITHOUT WARRANTY OF ANY KIND, either
* express or implied. See the LGPL for the specific language
* governing rights and limitations.
*
* You should have received a copy of the LGPL along with this
* program. If not, go to http://www.gnu.org/licenses/lgpl.html
* or write to the Free Software Foundation, Inc.,
* 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
*
* The development of this software was supported by the
* Excellence Cluster EXC 277 Cognitive Interaction Technology.
* The Excellence Cluster EXC 277 is a grant of the Deutsche
* Forschungsgemeinschaft (DFG) in the context of the German
* Excellence Initiative.
*
* Contributors: Leon Ziegler, Johannes Wienke, Matthias Schröder, Norman Köster,
* 				Lukas Twardon, Torben Töniges, Annika Rothert, Marian Pohling,
* 				Denis Schulze, Viktor Richter, Birte Carlmeyer, Maikel Linke
*/

/*
 * PoseData.cpp
 *
 *  Created on: May 25, 2010
 *      Author: ttoenige
 */

#include "PoseData.h"

using namespace airobots;
using namespace std;
using namespace xmltio;

std::string PoseData::getBaseTag()
{
	return "currentarmcoord";
}

std::string PoseData::getTemplate()
{
	return std::string("<") + getBaseTag() + "><GENERATOR/>"
			+ Timestamp::getTemplate() + "<currentxyz x=\"\" y=\"\" z=\"\" />"
			+ "</" + getBaseTag() + ">";
}

PoseData::PoseData() :
	Type("unknown")
{
	// TODO Auto-generated constructor stub

}

double PoseData::getX() const
{
	return x;
}
void PoseData::setX(double x)
{
	this->x = x;
}

double PoseData::getY() const
{
	return y;
}
void PoseData::setY(double y)
{
	this->y = y;
}

double PoseData::getZ() const
{
	return z;
}

void PoseData::setZ(double z)
{
	this->z = z;
}

void PoseData::sanitizeLocation(xmltio::Location &loc) const
{

}

void PoseData::fillInto(xmltio::Location &loc) const
{

	Type::fillInto(loc);

	loc[XPath("currentxyz/@x")] = getX();
	loc[XPath("currentxyz/@y")] = getY();
	loc[XPath("currentxyz/@z")] = getZ();

}

void PoseData::fromLocation(const xmltio::Location &loc_, PoseData &kpd)
{

	Type::fromLocation(loc_, kpd);

	kpd.setX(extract<double> (loc_[XPath("currentxyz/@x")]));
	kpd.setY(extract<double> (loc_[XPath("currentxyz/@y")]));
	kpd.setZ(extract<double> (loc_[XPath("currentxyz/@z")]));

}

