/*
* This file is part of Bielefeld Type Library (BTL).
*
* Copyright(c) Frederic Siepmann
* http://opensource.cit-ec.de/projects/btl
*
* This file may be licensed under the terms of of the
* GNU Lesser General Public License Version 3 (the ``LGPL''),
* or (at your option) any later version.
*
* Software distributed under the License is distributed
* on an ``AS IS'' basis, WITHOUT WARRANTY OF ANY KIND, either
* express or implied. See the LGPL for the specific language
* governing rights and limitations.
*
* You should have received a copy of the LGPL along with this
* program. If not, go to http://www.gnu.org/licenses/lgpl.html
* or write to the Free Software Foundation, Inc.,
* 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
*
* The development of this software was supported by the
* Excellence Cluster EXC 277 Cognitive Interaction Technology.
* The Excellence Cluster EXC 277 is a grant of the Deutsche
* Forschungsgemeinschaft (DFG) in the context of the German
* Excellence Initiative.
*
* Contributors: Leon Ziegler, Johannes Wienke, Matthias Schröder, Norman Köster,
* 				Lukas Twardon, Torben Töniges, Annika Rothert, Marian Pohling,
* 				Denis Schulze, Viktor Richter, Birte Carlmeyer, Maikel Linke
*/

/*
 * Type.cpp
 *
 *  Created on: Nov 4, 2009
 *      Author: jwienke
 */

#include "Type.h"

using namespace std;
using namespace xmltio;

namespace airobots {

const std::string Type::UNKNOWN_GENERATOR = "unknown";
const std::string Type::UNKNOWN_SOURCE_LOCATION = "<unknown/>";

Type::Type() :
	generator(UNKNOWN_GENERATOR), sourceLocation(UNKNOWN_SOURCE_LOCATION) {
}

Type::Type(const std::string &generator) :
	generator(generator), sourceLocation(UNKNOWN_SOURCE_LOCATION) {
}

Type::Type(const std::string &generator, const uint64_t &created) :
	generator(generator), sourceLocation(UNKNOWN_SOURCE_LOCATION), timestamp(created) {
}

Type::Type(const std::string &generator, const Timestamp &timestamp) :
	generator(generator), sourceLocation(UNKNOWN_SOURCE_LOCATION), timestamp(timestamp) {
}

std::string Type::getGenerator() const {
	return generator;
}

void Type::setGenerator(const std::string &generator) {
	this->generator = generator;
}

const Timestamp& Type::getTimestamp() const {
	return timestamp;
}

Timestamp& Type::getTimestamp() {
	return timestamp;
}

void Type::setTimestamp(const Timestamp &timestamp) {
	this->timestamp = timestamp;
}

const xmltio::Location& Type::getSourceLocation() const {
	if (sourceLocation.getDocumentText().compare(UNKNOWN_SOURCE_LOCATION) == 0)
		throw NoSourceLocationException();
	return sourceLocation;
}

xmltio::Location& Type::getSourceLocation() {
	if (sourceLocation.getDocumentText().compare(UNKNOWN_SOURCE_LOCATION) == 0)
		throw NoSourceLocationException();
	return sourceLocation;
}

void Type::setSourceLocation(const xmltio::Location &loc) {
	this->sourceLocation = loc;
}

bool Type::operator==(const Type &other) const {
	return (other.generator == generator) && (other.timestamp == timestamp);
}

void Type::setLegacyParsing(bool legacyParsing) {
	this->legacyParsing = legacyParsing;
}

bool Type::isLegacyParsing() const {
	return legacyParsing;
}

void Type::fillInto(xmltio::Location &loc) const {
	loc[XPath("GENERATOR")] = getGenerator();
	loc[XPath(Timestamp::getBaseTag())] = getTimestamp();
}

void Type::fromLocation(const xmltio::Location &loc, Type &type) {
	try{
		type.setGenerator(extract<string> (loc[XPath("GENERATOR")]));
		type.setTimestamp(extract<Timestamp> (loc[XPath(Timestamp::getBaseTag())]));
		type.setSourceLocation(loc);
	}
	catch(std::exception e){
		if(type.isLegacyParsing()) {
			cout << "Ignoring Exception because Legacy Parsing is on" << endl;
		}
		else {
			cout << "Error: Caught Exception and Legacy Parsing is off" << endl;
			exit(1);
		}
	}
}

}
