/*
* This file is part of Bielefeld Type Library (BTL).
*
* Copyright(c) Frederic Siepmann
* http://opensource.cit-ec.de/projects/btl
*
* This file may be licensed under the terms of of the
* GNU Lesser General Public License Version 3 (the ``LGPL''),
* or (at your option) any later version.
*
* Software distributed under the License is distributed
* on an ``AS IS'' basis, WITHOUT WARRANTY OF ANY KIND, either
* express or implied. See the LGPL for the specific language
* governing rights and limitations.
*
* You should have received a copy of the LGPL along with this
* program. If not, go to http://www.gnu.org/licenses/lgpl.html
* or write to the Free Software Foundation, Inc.,
* 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
*
* The development of this software was supported by the
* Excellence Cluster EXC 277 Cognitive Interaction Technology.
* The Excellence Cluster EXC 277 is a grant of the Deutsche
* Forschungsgemeinschaft (DFG) in the context of the German
* Excellence Initiative.
*
* Contributors: Leon Ziegler, Johannes Wienke, Matthias Schröder, Norman Köster,
* 				Lukas Twardon, Torben Töniges, Annika Rothert, Marian Pohling,
* 				Denis Schulze, Viktor Richter, Birte Carlmeyer, Maikel Linke
*/

#ifndef UNITCONVERTER_H_
#define UNITCONVERTER_H_

#include <exception>
#include <string>

#include "LengthUnit.h"
#include "AngleUnit.h"
#include "TimeUnit.h"

#define PI 3.141592653589793

namespace airobots {

/**
 * This helper class converts any value from any unit to any other unit.
 * For more details, refer to the documentation of the Java implementation.
 */
class UnitConverter {
public:
	/**
	 * This exception indicates, that a conversion can not be done, because one of the given units
	 * is not known to the converter.
	 */
	class UnknownUnitException : public std::exception {
	private:
		std::string message;
	public:
		UnknownUnitException(std::string message = "UnknownUnitException") {
			this->message = message;
		}

		~UnknownUnitException() throw() {}

		virtual const char* what() const throw() {
			return message.c_str();
		}
	};

	static int convert(int, LengthUnit, LengthUnit);
	static long convert(long, LengthUnit, LengthUnit);
	static double convert(double, LengthUnit, LengthUnit);
	static float convert(float, LengthUnit, LengthUnit);

	static double convert(double, AngleUnit, AngleUnit);
	static float convert(float, AngleUnit, AngleUnit);

	static long convert(long, TimeUnit, TimeUnit);

private:

	static double convertFrom(double, LengthUnit);
	static double convertTo(double, LengthUnit);
	static float convertFrom(float, LengthUnit);
	static float convertTo(float, LengthUnit);

	static double convertFrom(double, AngleUnit);
	static double convertTo(double, AngleUnit);
	static float convertFrom(float, AngleUnit);
	static float convertTo(float, AngleUnit);

	static long convertFrom(long, TimeUnit);
	static long convertTo(long, TimeUnit);

	static std::string unitName(LengthUnit);
	static std::string unitName(AngleUnit);
	static std::string unitName(TimeUnit);
};

}

#endif /* UNITCONVERTER_H_ */
