/*
 * This file is part of Bielefeld Type Library (BTL).
 * 
 * Copyright(c) Frederic Siepmann http://opensource.cit-ec.de/projects/btl
 * 
 * This file may be licensed under the terms of of the GNU Lesser General Public
 * License Version 3 (the ``LGPL''), or (at your option) any later version.
 * 
 * Software distributed under the License is distributed on an ``AS IS'' basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the LGPL for the
 * specific language governing rights and limitations.
 * 
 * You should have received a copy of the LGPL along with this program. If not,
 * go to http://www.gnu.org/licenses/lgpl.html or write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
 * USA.
 * 
 * The development of this software was supported by the Excellence Cluster EXC
 * 277 Cognitive Interaction Technology. The Excellence Cluster EXC 277 is a
 * grant of the Deutsche Forschungsgemeinschaft (DFG) in the context of the
 * German Excellence Initiative.
 * 
 * Contributors: Leon Ziegler, Johannes Wienke, Matthias Schröder, Norman
 * Köster, Lukas Twardon, Torben Töniges, Annika Rothert, Marian Pohling, Denis
 * Schulze, Viktor Richter, Birte Carlmeyer, Maikel Linke
 */
package de.unibi.airobots.btl.data.speechrec;

/**
 * Domain class representing a word in the speech recognizers output. Each part
 * is associated with an acoustic, a language model and a combined score.
 * 
 * @author lschilli
 */
public class UtterancePart implements GrammarSymbol {

	private String word;
	private int id;
	private int begin;
	private int end;
	private double acousticScore;
	private double lmScore;
	private double combinedScore;

	public String getWord() {
		return word;
	}

	public void setWord(String word) {
		this.word = word;
	}

	public int getId() {
		return id;
	}

	public void setId(int id) {
		this.id = id;
	}

	public int getBegin() {
		return begin;
	}

	public void setBegin(int begin) {
		this.begin = begin;
	}

	public int getEnd() {
		return end;
	}

	public void setEnd(int end) {
		this.end = end;
	}

	public double getAcousticScore() {
		return acousticScore;
	}

	public void setAcousticScore(double acousticScore) {
		this.acousticScore = acousticScore;
	}

	public double getLmScore() {
		return lmScore;
	}

	public void setLmScore(double lmScore) {
		this.lmScore = lmScore;
	}

	public double getCombinedScore() {
		return combinedScore;
	}

	public void setCombinedScore(double combinedScore) {
		this.combinedScore = combinedScore;
	}

	/**
	 * {@inheritDoc}
	 */
	@Override
	public String toString() {
		return word + "[" + begin + ".." + end + "]";
	}

}