/*
* This file is part of Bielefeld Type Library (BTL).
*
* Copyright(c) Frederic Siepmann
* http://opensource.cit-ec.de/projects/btl
*
* This file may be licensed under the terms of of the
* GNU Lesser General Public License Version 3 (the ``LGPL''),
* or (at your option) any later version.
*
* Software distributed under the License is distributed
* on an ``AS IS'' basis, WITHOUT WARRANTY OF ANY KIND, either
* express or implied. See the LGPL for the specific language
* governing rights and limitations.
*
* You should have received a copy of the LGPL along with this
* program. If not, go to http://www.gnu.org/licenses/lgpl.html
* or write to the Free Software Foundation, Inc.,
* 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
*
* The development of this software was supported by the
* Excellence Cluster EXC 277 Cognitive Interaction Technology.
* The Excellence Cluster EXC 277 is a grant of the Deutsche
* Forschungsgemeinschaft (DFG) in the context of the German
* Excellence Initiative.
*
* Contributors: Leon Ziegler, Johannes Wienke, Matthias Schröder, Norman Köster,
* 				Lukas Twardon, Torben Töniges, Annika Rothert, Marian Pohling,
* 				Denis Schulze, Viktor Richter, Birte Carlmeyer, Maikel Linke
*/
package de.unibi.airobots.btl.data;

import static org.junit.Assert.*;

import java.util.Iterator;

import nu.xom.Builder;
import nu.xom.Document;
import nu.xom.Element;

import org.apache.log4j.Logger;
import org.junit.Test;

import de.unibi.airobots.btl.TestUtils;
import de.unibi.airobots.btl.common.Timestamp;
import de.unibi.airobots.btl.data.NavigationGoalData.GoalType;

/**
 * Test cases for {@link Type}.
 * 
 * @author jwienke
 */
public class GlobalPlanTest {

	private Logger logger = Logger.getLogger(getClass());

	@Test
	public void selfCompatibility() throws Exception {

		GlobalPlan original = new GlobalPlan();
		final long timestamp = System.currentTimeMillis();
		original.setTimestamp(timestamp);
		original.setGenerator("test");
		original.add(new NavigationGoalData("test1", 12.5, 0.35, 2.48, 0.5,
				0.42, GoalType.LOCAL));
		original.add(new NavigationGoalData("test2", -12.59, 0.3765, 1.48, 0.1,
				0.942, GoalType.LOCAL));
		original.add(new NavigationGoalData("test3", 123.5, -50.35, 2.48, 0.2,
				0.142, GoalType.LOCAL));
		original.add(new NavigationGoalData("test4", 132.5, -45.35, 4.48, 0.3,
				0.242, GoalType.LOCAL));
		original.add(new NavigationGoalData("test5", -1222.5, 0.385, -0.48,
				0.9, 0.342, GoalType.LOCAL));

		Document doc = new Document(new Element(GlobalPlan.getBaseTag()));
		original.fillInto(doc.getRootElement());
		logger.info(doc.toXML());

		GlobalPlan parsed = new GlobalPlan();
		GlobalPlan.fromElement(doc.getRootElement(), parsed);

		assertEquals(original.getGenerator(), parsed.getGenerator());
		assertEquals(original.getTimestamp(), parsed.getTimestamp());
		assertEquals(original.size(), parsed.size());
		Iterator<NavigationGoalData> originalIt = original.iterator();
		Iterator<NavigationGoalData> parsedIt = parsed.iterator();
		while (originalIt.hasNext() && parsedIt.hasNext()) {
			PositionData ongd = originalIt.next();
			PositionData pngd = parsedIt.next();

			assertEquals(ongd, pngd);

			// ensure that both iterators have the same size
			assertTrue(!(originalIt.hasNext() ^ parsedIt.hasNext()));
		}

	}

	@Test
	public void fileCompatibility() throws Exception {

		Builder parser = new Builder();
		Document doc = parser.build(TestUtils
				.makeTestFileName("GlobalPlan.xml"));

		GlobalPlan parsed = new GlobalPlan();
		GlobalPlan.fromElement(doc.getRootElement(), parsed);
		assertEquals(doc.getRootElement().getLocalName(), GlobalPlan
				.getBaseTag());

		assertEquals("test", parsed.getGenerator());
		assertEquals(new Timestamp(12345, 67890), parsed.getTimestamp());
		assertEquals(3, parsed.size());

		// XXX stub test to ensure that hopefully all three entries are parsed
		// in the correct order
		assertEquals(0.177, parsed.get(0).getCoordinateTolerance(), 0.0001);
		assertEquals(0.277, parsed.get(1).getCoordinateTolerance(), 0.0001);
		assertEquals(0.377, parsed.get(2).getCoordinateTolerance(), 0.0001);

	}

}
