/*
* This file is part of Bielefeld Type Library (BTL).
*
* Copyright(c) Frederic Siepmann
* http://opensource.cit-ec.de/projects/btl
*
* This file may be licensed under the terms of of the
* GNU Lesser General Public License Version 3 (the ``LGPL''),
* or (at your option) any later version.
*
* Software distributed under the License is distributed
* on an ``AS IS'' basis, WITHOUT WARRANTY OF ANY KIND, either
* express or implied. See the LGPL for the specific language
* governing rights and limitations.
*
* You should have received a copy of the LGPL along with this
* program. If not, go to http://www.gnu.org/licenses/lgpl.html
* or write to the Free Software Foundation, Inc.,
* 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
*
* The development of this software was supported by the
* Excellence Cluster EXC 277 Cognitive Interaction Technology.
* The Excellence Cluster EXC 277 is a grant of the Deutsche
* Forschungsgemeinschaft (DFG) in the context of the German
* Excellence Initiative.
*
* Contributors: Leon Ziegler, Johannes Wienke, Matthias Schröder, Norman Köster,
* 				Lukas Twardon, Torben Töniges, Annika Rothert, Marian Pohling,
* 				Denis Schulze, Viktor Richter, Birte Carlmeyer, Maikel Linke
*/
package de.unibi.airobots.btl.data;

import static org.junit.Assert.*;

import nu.xom.Builder;
import nu.xom.Document;
import nu.xom.Element;

import org.apache.log4j.Logger;
import org.junit.Test;

import de.unibi.airobots.btl.TestUtils;
import de.unibi.airobots.btl.common.Point3D;
import de.unibi.airobots.btl.common.Polygon;
import de.unibi.airobots.btl.common.PrecisePolygon3D;
import de.unibi.airobots.btl.common.Timestamp;
import de.unibi.airobots.btl.data.Path3DData.Scope;
import de.unibi.airobots.btl.units.LengthUnit;

/**
 * Test cases for {@link Type}.
 * 
 * @author ltwardon
 */
public class Path3DDataTest {

	private Logger logger = Logger.getLogger(getClass());

	@Test
	public void selfCompatibility() throws Exception {

		PrecisePolygon3D polygon = new PrecisePolygon3D();
		polygon.addPoint(0, 0, 0, LengthUnit.MILLIMETER);
		polygon.addPoint(1, 1, 1, LengthUnit.MILLIMETER);
		polygon.addPoint(2, 2, 2, LengthUnit.MILLIMETER);
		
		Path3DData original = new Path3DData(polygon, Scope.LOCAL);

		assertEquals(original.getPolygon().getMinX(LengthUnit.MILLIMETER), original.getPolygon().getMinX(LengthUnit.CENTIMETER) * 10, 0.0001);
		assertEquals(original.getPolygon().getMinX(LengthUnit.MILLIMETER), original.getPolygon().getMinX(LengthUnit.METER) * 1000, 0.0001);
		assertEquals(original.getPolygon().getMaxY(LengthUnit.MILLIMETER), original.getPolygon().getMaxY(LengthUnit.CENTIMETER) * 10, 0.0001);
		assertEquals(original.getPolygon().getMaxZ(LengthUnit.MILLIMETER), original.getPolygon().getMaxZ(LengthUnit.METER) * 1000, 0.0001);
		
		Document doc = new Document(new Element(Path3DData.getBaseTag()));
		original.fillInto(doc.getRootElement());
		logger.info(doc.toXML());

		Path3DData parsed = new Path3DData();
		Path3DData.fromElement(doc.getRootElement(), parsed);
		
		assertEquals(original.getGenerator(), parsed.getGenerator());
		assertEquals(original.getTimestamp(), parsed.getTimestamp());
		assertEquals(original.getScope(), parsed.getScope());
		assertEquals(original.getPolygon().getMaxX(LengthUnit.MILLIMETER), parsed.getPolygon().getMaxX(LengthUnit.MILLIMETER), 0.0001);
		assertEquals(original.getPolygon().getMinY(LengthUnit.MILLIMETER), parsed.getPolygon().getMinY(LengthUnit.MILLIMETER), 0.0001);
		assertEquals(original.getPolygon().getMinZ(LengthUnit.MILLIMETER), parsed.getPolygon().getMinZ(LengthUnit.MILLIMETER), 0.0001);
		
	}

	@Test
	public void fileCompatibility() throws Exception {

		Builder parser = new Builder();
		Document doc = parser.build(TestUtils.makeTestFileName("Path3DData.xml"));
		
		Path3DData parsed = new Path3DData();
		Path3DData.fromElement(doc.getRootElement(), parsed);
		assertEquals(doc.getRootElement().getLocalName(), Path3DData.getBaseTag());
		
		assertEquals("PlaneDetector", parsed.getGenerator());
		assertEquals(new Timestamp(253543797, 253543712), parsed.getTimestamp());
		assertEquals(Scope.LOCAL, parsed.getScope());
		
		double count = 0.0;
		for(Point3D point : parsed.getPolygon()) {
			assertEquals(count, point.getX(LengthUnit.MILLIMETER), 0.0001);
			assertEquals(count, point.getY(LengthUnit.MILLIMETER), 0.0001);
			assertEquals(count, point.getZ(LengthUnit.MILLIMETER), 0.0001);
			count++;
		}
		
	}

	
}
